#! /usr/bin/env python2.4
# Script for test/run the project on Unix or Windows. For use setup
# ZOPE_INSTANCE environment variable first.
#
# Copyright (C) 2008 Dmitry Vasiliev <dima@hlabs.spb.ru>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

__author__ = "Dmitry Vasiliev <dima@hlabs.spb.ru>"

import os
import sys
import subprocess

I18N_DOMAIN = "clock"
PACKAGE = "clock"


def create_ftesting_zcml():
    zcml_path = os.path.join(path, "etc", "ftesting.zcml")
    if not os.path.exists(zcml_path):
        zcml_path = os.path.join(path, "ftesting.zcml")
        if not os.path.exists(zcml_path):
            raise ValueError("not found ftesting.zcml")
    content = """<configure
        xmlns="http://namespaces.zope.org/zope"
        i18n_domain="%s">
        <include file="%s"/>
        <include package="%s"/>
        </configure>""" % (I18N_DOMAIN, zcml_path, PACKAGE)
    f = open("ftesting.zcml", "wb")
    try:
        f.write(content)
    finally:
        f.close()

def execute(*args):
    try:
        rc = subprocess.call(args, env={"PYTHONPATH": os.path.join(here, "src")})
    except KeyboardInterrupt:
        rc = 0
    sys.exit(rc)

def test(args):
    test_path = os.path.join(path, "bin", "test")
    if not os.path.exists(test_path):
        test_path = os.path.join(path, "test.py")
        if not os.path.exists(test_path):
            raise ValueError("not found test script")
    try:
        execute(sys.executable, test_path, "--test-path", "src", *args)
    finally:
        os.unlink("ftesting.zcml")

def run(args):
    run_path = os.path.join(path, "z3.py")
    if not os.path.exists(run_path):
        run_path = os.path.join(path, "bin", "runzope")
        if not os.path.exists(run_path):
            raise ValueError("not found run script")
    else:
        os.chdir(path)
    execute(sys.executable, run_path, *args)

def i18n(args):
    i18n_path = os.path.join(path, "bin", "i18nextract")
    if not os.path.exists(i18n_path):
        i18n_path = os.path.join(path, "utilities", "i18nextract.py")
        if not os.path.exists(i18n_path):
            raise ValueError("not found i18n script")
    execute(sys.executable, i18n_path, "-d", I18N_DOMAIN, "-p",
        "src/%s" % PACKAGE, "-o", "locales", *args)

def main(args=None):
    global path, here

    if args is None:
        args = sys.argv[1:]
    if not args:
        print >> sys.stderr, "Usage: box.py (test, run, i18n)"
        sys.exit(2)

    here = os.getcwdu()

    try:
        path = os.environ["ZOPE_INSTANCE"]
    except KeyError:
        print >> sys.stderr, (
            "Error: No ZOPE_INSTANCE environment variable found")
        sys.exit(1)

    command = args[0]
    if command == "test":
        create_ftesting_zcml()
        test(args[1:])
    elif command == "run":
        run(args[1:])
    elif command == "i18n":
        i18n(args[1:])
    else:
        print >> sys.stderr, "Unknown command: %r" % command
        sys.exit(2)


if __name__ == "__main__":
    main()
